#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-b280ccc19afbd942da03aa8e46087198
key: vecto_EAIqXashL2KA81Be2eG5qr
license: BSD3
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
author: Liyang HU <vector-th-unbox@liyang.hu>
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-EAIqXashL2KA81Be2eG5qr
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
